==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/UserArtifactSourceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.UserArtifactSourceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The source image from which the Image Version is going to be created.
 * @property defaultConfigurationLink Optional. The defaultConfigurationLink of the artifact, must be a readable storage page blob.
 * @property mediaLink Required. The mediaLink of the artifact, must be a readable storage page blob.
 */
public data class UserArtifactSourceArgs(
    public val defaultConfigurationLink: Output<String>? = null,
    public val mediaLink: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.UserArtifactSourceArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.UserArtifactSourceArgs =
        com.pulumi.azurenative.compute.inputs.UserArtifactSourceArgs.builder()
            .defaultConfigurationLink(defaultConfigurationLink?.applyValue({ args0 -> args0 }))
            .mediaLink(mediaLink.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [UserArtifactSourceArgs].
 */
@PulumiTagMarker
public class UserArtifactSourceArgsBuilder internal constructor() {
    private var defaultConfigurationLink: Output<String>? = null

    private var mediaLink: Output<String>? = null

    /**
     * @param value Optional. The defaultConfigurationLink of the artifact, must be a readable storage page blob.
     */
    @JvmName("xohfdaumaighjqrt")
    public suspend fun defaultConfigurationLink(`value`: Output<String>) {
        this.defaultConfigurationLink = value
    }

    /**
     * @param value Required. The mediaLink of the artifact, must be a readable storage page blob.
     */
    @JvmName("hyccgdukjuwielgv")
    public suspend fun mediaLink(`value`: Output<String>) {
        this.mediaLink = value
    }

    /**
     * @param value Optional. The defaultConfigurationLink of the artifact, must be a readable storage page blob.
     */
    @JvmName("rhtdctwllvfdkwkt")
    public suspend fun defaultConfigurationLink(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultConfigurationLink = mapped
    }

    /**
     * @param value Required. The mediaLink of the artifact, must be a readable storage page blob.
     */
    @JvmName("spdskymvpeomtfxs")
    public suspend fun mediaLink(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mediaLink = mapped
    }

    internal fun build(): UserArtifactSourceArgs = UserArtifactSourceArgs(
        defaultConfigurationLink = defaultConfigurationLink,
        mediaLink = mediaLink ?: throw PulumiNullFieldException("mediaLink"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/UserArtifactSourceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.UserArtifactSourceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The source image from which the Image Version is going to be created.
 * @property defaultConfigurationLink Optional. The defaultConfigurationLink of the artifact, must be a readable storage page blob.
 * @property mediaLink Required. The mediaLink of the artifact, must be a readable storage page blob.
 */
public data class UserArtifactSourceArgs(
    public val defaultConfigurationLink: Output<String>? = null,
    public val mediaLink: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.UserArtifactSourceArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.UserArtifactSourceArgs =
        com.pulumi.azurenative.compute.inputs.UserArtifactSourceArgs.builder()
            .defaultConfigurationLink(defaultConfigurationLink?.applyValue({ args0 -> args0 }))
            .mediaLink(mediaLink.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [UserArtifactSourceArgs].
 */
@PulumiTagMarker
public class UserArtifactSourceArgsBuilder internal constructor() {
    private var defaultConfigurationLink: Output<String>? = null

    private var mediaLink: Output<String>? = null

    /**
     * @param value Optional. The defaultConfigurationLink of the artifact, must be a readable storage page blob.
     */
    @JvmName("qmuxatnpqgovfoos")
    public suspend fun defaultConfigurationLink(`value`: Output<String>) {
        this.defaultConfigurationLink = value
    }

    /**
     * @param value Required. The mediaLink of the artifact, must be a readable storage page blob.
     */
    @JvmName("lcyvplnwskkdacen")
    public suspend fun mediaLink(`value`: Output<String>) {
        this.mediaLink = value
    }

    /**
     * @param value Optional. The defaultConfigurationLink of the artifact, must be a readable storage page blob.
     */
    @JvmName("lvdiecsjinwcwyrv")
    public suspend fun defaultConfigurationLink(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultConfigurationLink = mapped
    }

    /**
     * @param value Required. The mediaLink of the artifact, must be a readable storage page blob.
     */
    @JvmName("hhssyxfopsyeaopr")
    public suspend fun mediaLink(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mediaLink = mapped
    }

    internal fun build(): UserArtifactSourceArgs = UserArtifactSourceArgs(
        defaultConfigurationLink = defaultConfigurationLink,
        mediaLink = mediaLink ?: throw PulumiNullFieldException("mediaLink"),
    )
}
